@@ -60,6 +60,7 @@ static int makeBidError(const pageInfo_t *pageInfo, auctionInfo *aip);
 static int match(memBuf_t *mp, const char *str);
 static int parseBid(memBuf_t *mp, auctionInfo *aip);
 static int preBid(auctionInfo *aip);
+static int parsePreBid(memBuf_t *mp, auctionInfo *aip);
 static int printMyItemsRow(char **row, int printNewline);
 static int watch(auctionInfo *aip);
 
@@ -298,8 +299,19 @@ preBid(auctionInfo *aip)
 	if (!mp)
 		return httpError(aip);
 
+	ret = parsePreBid(mp, aip);
+	freeMembuf(mp);
+	return ret;
+}
+
+static int
+parsePreBid(memBuf_t *mp, auctionInfo *aip)
+{
+	int ret = 0;
+	int found = 0;
+
 	/* pagename should be PageReviewBidBottomButton, but don't check it */
-	while (found < 7 && !match(mp, "<input type=\"hidden\" name=\"")) {
+	while (found < 3 && !match(mp, "<input type=\"hidden\" name=\"")) {
 		if (!strncmp(mp->readptr, "key\"", 4)) {
 			char *cp, *tmpkey;
 
@@ -328,15 +340,9 @@ preBid(auctionInfo *aip)
 			free(aip->biduiid);
 			aip->biduiid = myStrdup(getUntil(mp, '\"'));
 			log(("preBid(): biduiid is \"%s\"", aip->biduiid));
-		} else if (!strncmp(mp->readptr, "pass\"", 5)) {
-			found |= 0x04;
-			match(mp, "value=\"");
-			free(aip->bidpass);
-			aip->bidpass = myStrdup(getUntil(mp, '\"'));
-			log(("preBid(): bidpass is \"%s\"", aip->bidpass));
 		}
 	}
-	if (found < 7) {
+	if (found < 3) {
 		pageInfo_t *pageInfo = getPageInfo(mp);
 
 		ret = makeBidError(pageInfo, aip);
@@ -346,7 +352,6 @@ preBid(auctionInfo *aip)
 		}
 		freePageInfo(pageInfo);
 	}
-	freeMembuf(mp);
 	return ret;
 }
 
@@ -432,7 +437,9 @@ ebayLogin(auctionInfo *aip, time_t interval)
 			 !strncasecmp(pp->pageName, "My eBay", 7))
 		    ))
 			loginTime = time(NULL);
-		else if (pp->pageName && !strcmp(pp->pageName, "Welcome to eBay"))
+		else if (pp->pageName &&
+				(!strcmp(pp->pageName, "Welcome to eBay") ||
+				 !strcmp(pp->pageName, "Welcome to eBay - Sign in - Error")))
 			ret = auctionError(aip, ae_badpass, NULL);
 		else if (pp->pageName && !strcmp(pp->pageName, "PageSignIn"))
 			ret = auctionError(aip, ae_login, NULL);
@@ -581,7 +588,7 @@ parseBid(memBuf_t *mp, auctionInfo *aip)
 	return ret;
 } /* parseBid() */
 
-static const char BID_URL[] = "http://%s/ws/eBayISAPI.dll?MfcISAPICommand=MakeBid&BIN_button=Confirm%%20Bid&item=%s&key=%s&maxbid=%s&quant=%s&user=%s&pass=%s&uiid=%s&javascriptenabled=0&mode=1";
+static const char BID_URL[] = "http://%s/ws/eBayISAPI.dll?MfcISAPICommand=MakeBid&BIN_button=Confirm%%20Bid&item=%s&key=%s&maxbid=%s&quant=%s&user=%s&uiid=%s&javascriptenabled=0&mode=1";
 
 /*
  * Place bid.
@@ -595,12 +602,12 @@ bid(auctionInfo *aip)
 {
 	memBuf_t *mp = NULL;
 	size_t urlLen;
-	char *url, *logUrl, *tmpUsername, *tmpPassword, *tmpUiid;
+	char *url, *logUrl, *tmpUsername, *tmpUiid;
 	int ret;
 	int quantity = getQuantity(options.quantity, aip->quantity);
 	char quantityStr[12];	/* must hold an int */
 
-	if (!aip->bidkey || !aip->bidpass || !aip->biduiid)
+	if (!aip->bidkey || !aip->biduiid)
 		return auctionError(aip, ae_bidkey, NULL);
 
 	if (ebayLogin(aip, 0))
@@ -608,17 +615,15 @@ bid(auctionInfo *aip)
 	sprintf(quantityStr, "%d", quantity);
 
 	/* create url */
-	urlLen = sizeof(BID_URL) + strlen(options.bidHost) + strlen(aip->auction) + strlen(aip->bidkey) + strlen(aip->bidPriceStr) + strlen(quantityStr) + strlen(options.usernameEscape) + strlen(aip->bidpass) + strlen(aip->biduiid) - (8*2);
+	urlLen = sizeof(BID_URL) + strlen(options.bidHost) + strlen(aip->auction) + strlen(aip->bidkey) + strlen(aip->bidPriceStr) + strlen(quantityStr) + strlen(options.usernameEscape) + strlen(aip->biduiid) - (7*2);
 	url = (char *)myMalloc(urlLen);
-	sprintf(url, BID_URL, options.bidHost, aip->auction, aip->bidkey, aip->bidPriceStr, quantityStr, options.usernameEscape, aip->bidpass, aip->biduiid);
+	sprintf(url, BID_URL, options.bidHost, aip->auction, aip->bidkey, aip->bidPriceStr, quantityStr, options.usernameEscape, aip->biduiid);
 
 	logUrl = (char *)myMalloc(urlLen);
 	tmpUsername = stars(strlen(options.usernameEscape));
-	tmpPassword = stars(strlen(aip->bidpass));
 	tmpUiid = stars(strlen(aip->biduiid));
-	sprintf(logUrl, BID_URL, options.bidHost, aip->auction, aip->bidkey, aip->bidPriceStr, quantityStr, tmpUsername, tmpPassword, tmpUiid);
+	sprintf(logUrl, BID_URL, options.bidHost, aip->auction, aip->bidkey, aip->bidPriceStr, quantityStr, tmpUsername, tmpUiid);
 	free(tmpUsername);
-	free(tmpPassword);
 	free(tmpUiid);
 
 	if (!options.bid) {
@@ -899,7 +904,7 @@ printMyItemsRow(char **row, int printNewline)
 	const char *myitems_description[MAX_TDS][MAX_TDS_LENGTH] = {
 		{0, 0, 0, 0, 0, 0},
 		{0, 0, 0, 0, 0, 0},
-		{"Description:\t%s\n", "Seller:\t\t%s", 0, "(%s)", 0,"/%s\n"},
+		{"Description:\t%s\n", 0, "Seller:\t\t%s", 0, 0," (%s)\n"},
 		{ "Bids:\t\t%s\n", 0, 0, 0, 0, 0},
 		{ "Price:\t\t%s\n", 0, 0, 0, 0, 0},
 		{ "Shipping:\t%s\n", 0, 0, 0, 0, 0},
@@ -1087,5 +1092,15 @@ testParser(int flag)
 		}
 		break;
 	    }
+	case 5:
+		{
+		/* run through prebid parser */
+		auctionInfo *aip = newAuctionInfo("1", "2");
+		int ret = parsePreBid(mp, aip);
+
+		printf("ret = %d\n", ret);
+		printAuctionError(aip, stdout);
+		break;
+		}
 	}
 }
